@@ -31,6 +31,7 @@
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
 
+#include <stdbool.h>
 #include <stdio.h>
 #include <assert.h>
 #include <sys/types.h>
@@ -61,6 +62,7 @@
 #endif /* !ARG_MAX */
 
 #include "argp.h"
+#include "gl_list.h"
 #include "progname.h"
 
 #include "gettext.h"
@@ -72,6 +74,7 @@
 
 #include "cleanup.h"
 #include "error.h"
+#include "glcontainers.h"
 #include "pipeline.h"
 #include "sandbox.h"
 
@@ -110,7 +113,7 @@ static error_t parse_opt (int key, char *arg, struct argp_state *state)
 
 	switch (key) {
 		case 'd':
-			debug_level = 1;
+			debug_level = true;
 			return 0;
 		case 'M':
 			manp = arg;
@@ -164,7 +167,7 @@ static struct argp argp = { options, parse_opt, args_doc };
 
 static char *locale;
 
-static char *manpathlist[MAXDIRS];
+static gl_list_t manpathlist;
 
 static void post_fork (void)
 {
@@ -353,7 +356,7 @@ static int check_access (const char *directory)
 int main (int argc, char *argv[])
 {
 	char *sys_manp;
-	char **mp;
+	char *mp;
 	const char **sp;
 
 	set_program_name (argv[0]);
@@ -388,14 +391,14 @@ int main (int argc, char *argv[])
 
 	debug ("manpath=%s\n", manp);
 
-	/* get the manpath as an array of pointers */
-	create_pathlist (manp, manpathlist); 
-	
-	for (mp = manpathlist; *mp; mp++) {
+	/* get the manpath as a list of pointers */
+	manpathlist = create_pathlist (manp); 
+
+	GL_LIST_FOREACH_START (manpathlist, mp) {
 		char *catpath;
 		size_t len;
 
-		catpath = get_catpath (*mp, SYSTEM_CAT | USER_CAT);
+		catpath = get_catpath (mp, SYSTEM_CAT | USER_CAT);
 
 		if (catpath) { 
 			if (is_directory (catpath) != 1) {
@@ -404,10 +407,10 @@ int main (int argc, char *argv[])
 			}
 			database = mkdbname (catpath);
 		} else {
-			if (is_directory (*mp) != 1)
+			if (is_directory (mp) != 1)
 				continue;
-			database = mkdbname (*mp);
-			catpath = xstrdup (*mp);
+			database = mkdbname (mp);
+			catpath = xstrdup (mp);
 		}
 
 		len = strlen (catpath);
@@ -419,14 +422,14 @@ int main (int argc, char *argv[])
 				continue;
 			if (check_access (catpath))
 				continue;
-			if (parse_for_sec (*mp, *sp)) {
-				error (0, 0, _("unable to update %s"), *mp);
+			if (parse_for_sec (mp, *sp)) {
+				error (0, 0, _("unable to update %s"), mp);
 				break;
 			}
 		}
 			
 		free (catpath);
-	}
+	} GL_LIST_FOREACH_END (manpathlist);
 
 	free_pathlist (manpathlist);
 	free (locale);
