@@ -27,9 +27,11 @@
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
 
+#include <stdbool.h>
 #include <stdlib.h>
 
 #include "argp.h"
+#include "gl_list.h"
 #include "progname.h"
 #include "xvasprintf.h"
 
@@ -52,7 +54,7 @@
 int quiet = 1;
 man_sandbox *sandbox;
 
-static char *manpathlist[MAXDIRS];
+static gl_list_t manpathlist;
 
 static char **files;
 static int num_files;
@@ -75,7 +77,7 @@ static error_t parse_opt (int key, char *arg ATTRIBUTE_UNUSED,
 {
 	switch (key) {
 		case 'd':
-			debug_level = 1;
+			debug_level = true;
 			return 0;
 		case 'C':
 			return 0; /* compatibility with GNU soelim */
@@ -140,7 +142,7 @@ int main (int argc, char *argv[])
 	manp = add_nls_manpaths (get_manpath (NULL), all_locales);
 	free (all_locales);
 
-	create_pathlist (manp, manpathlist);
+	manpathlist = create_pathlist (manp);
 
 	/* parse files in command line order */
 	for (i = 0; i < num_files; ++i) {
@@ -152,6 +154,7 @@ int main (int argc, char *argv[])
 	free_pathlist (manpathlist);
 	free (manp);
 	free (internal_locale);
+	sandbox_free (sandbox);
 
 	return OK;
 }
